==> bygfoot_1.6.3.orig.tar.gz: bygfoot-1.6.3.orig/src/options_callbacks.h <==
#include <gtk/gtk.h>

void
on_button_opt_ok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_opt_cancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_check_show_live_toggled             (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_check_notify_bound_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button_opt_change_font_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_spin_live_duration_activate         (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_button_notify_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_notify_ok_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_notify_cancel_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_checkbutton_notify_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_autosave_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_sort_transfers_toggled  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

==> bygfoot_1.8.0.orig.tar.gz: bygfoot-1.8.0.orig/src/options_callbacks.h <==
#ifndef OPTIONS_CALLBACKS_H
#define OPTIONS_CALLBACKS_H

#include "bygfoot.h"
#include "variables.h"

void
on_button_opt_ok_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_button_opt_cancel_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_check_show_live_toggled             (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_check_notify_bound_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_button_opt_change_font_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_spin_live_duration_activate         (GtkEntry        *entry,
                                        gpointer         user_data);

void
on_checkbutton_notify_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_autosave_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkbutton_sort_transfers_toggled  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

#endif

gboolean
on_opt_window_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);
